@@ -496,7 +496,7 @@ void writeGtkThemeControlFile(int forceRecreate) {
 	// Menu items
 	{
 		TQStringList objectTypes;
-		objectTypes.append(TQPOPUPMENU_OBJECT_NAME_STRING);
+		objectTypes.append("TQPopupMenu");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 		setColour("color", "hover:insensitive", objectPalette.color(TQPalette::Disabled, TQColorGroup::Text), "GtkMenu>GtkMenuItem");
 // 		setColour("color", "hover:normal", objectPalette.color(TQPalette::Active, TQColorGroup::HighlightedText), "GtkMenu>GtkMenuItem");
@@ -751,7 +751,7 @@ void writeGtkThemeControlFile(int forceRecreate) {
 	
 	if (!forceRecreate && themeFile.exists()) {
 		themeFile.open(IO_ReadOnly);
-		stream.setDevice(TQT_TQIODEVICE(&themeFile));
+		stream.setDevice(&themeFile);
 		
 		if (stream.readLine() == "/* " + iconTheme + ", " + tqApp->style().name() + ", " + RC_CACHE_VERSION + ", " + __DATE__ + ", " + __TIME__  + " */") {
 			// This cache matches the current icon theme and style
@@ -771,7 +771,7 @@ void writeGtkThemeControlFile(int forceRecreate) {
 	}
 	
 	themeFile.open(IO_WriteOnly | IO_Truncate);
-	stream.setDevice(TQT_TQIODEVICE(&themeFile));
+	stream.setDevice(&themeFile);
 
 	stream << "/* " << iconTheme << ", " << tqApp->style().name() << ", " << RC_CACHE_VERSION << ", " << __DATE__ << ", " << __TIME__ << " */\n\n";
 	stream << "/* This file was generated by the Gtk TQt Theme Engine */\n";
@@ -909,7 +909,7 @@ void writeGtkThemeControlFile(int forceRecreate) {
 		probeRect = TQRect(0, 0, 100, 100);
 
 		TQStringList objectTypes;
-		objectTypes.append(TQCOMBOBOX_OBJECT_NAME_STRING);
+		objectTypes.append("TQComboBox");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		TQStyleControlElementData ceData;
@@ -956,7 +956,7 @@ void writeGtkThemeControlFile(int forceRecreate) {
 	// See upstream GTK bug #687363
 	{
 		TQStringList objectTypes;
-		objectTypes.append(TQTEXTEDIT_OBJECT_NAME_STRING);
+		objectTypes.append("TQTextEdit");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 // 		stream << parse_rc_string("background-color: " + colorString(objectPalette.color(TQPalette::Active, TQColorGroup::Base)), "GtkTextView");
 // 		stream << parse_rc_string("background-color: " + colorString(objectPalette.color(TQPalette::Disabled, TQColorGroup::Base)), "GtkTextView:insensitive");
@@ -973,7 +973,7 @@ void writeGtkThemeControlFile(int forceRecreate) {
 	int tdeMenuFrameWidth;
 	{
 		TQStringList objectTypes;
-		objectTypes.append(TQPOPUPMENU_OBJECT_NAME_STRING);
+		objectTypes.append("TQPopupMenu");
 		TQPalette objectPalette = tqApp->palette(objectTypes);
 
 		TQStyleControlElementData ceData;
