@@ -36,8 +36,6 @@
 #include <kpixmapio.h>
 #endif // USE_TDE_SPECIFIC_LIBRARIES
 
-#undef Qt
-
 #define CAIRO_PEN_PIXEL_OFFSET (0.5)
 #define CAIRO_BRUSH_PIXEL_OFFSET (0.0)
 #define CAIRO_FONT_SIZE_FUDGE_FACTOR (1.4)
@@ -1198,7 +1196,7 @@ void TQt3CairoPaintDevice::setCairoTransformations(cairo_t* cr, bool forceDisabl
 /*!
     \class TQt3CairoPaintDevice tdeqt4painter.h
     \brief The TQt3CairoPaintDevice class is a paint device that translates
-    Qt paint events to a TQt painter.
+    TQt paint events to a TQt painter.
 
     \ingroup graphics
     \ingroup shared
